@@ -1,4 +1,4 @@
-/* 22nov21 Software Lab. Alexander Burger */
+/* 04sep22 Software Lab. Alexander Burger */
 
 function renderCanvas(cvs, lst) {
    var ctx = cvs.getContext("2d");
@@ -159,16 +159,13 @@ function renderCanvas(cvs, lst) {
 function drawCanvas(id, dly) {
    var req = new XMLHttpRequest();
    var url = document.getElementsByTagName("BASE")[0].href + SesId + "!jsDraw?" + id + "&+" + dly;
-   var len = arguments.length;
+   var flg = arguments[2];
 
-   for (var i = 2; i < len; ++i) {
-      if (typeof arguments[i] == "undefined")
-         return true;
+   for (var i = 2; i < arguments.length; ++i)
       if (typeof arguments[i] === "number")
          url += "&+" + arguments[i];
       else
          url += "&" + arguments[i];
-   }
    try {req.open("POST", url);}
    catch (e) {return true;}
    req.responseType = "arraybuffer";
@@ -187,9 +184,12 @@ function drawCanvas(id, dly) {
          }
       }
       if (ele.dly == 0)
-         requestAnimationFrame(function() {drawCanvas(id, dly)});
-      else if (ele.dly > 0)
-         setTimeout(function() {drawCanvas(id, dly)}, ele.dly);
+         requestAnimationFrame(function() {drawCanvas(id, dly, "$T")});
+      else if (!flg  &&  ele.dly > 0) {
+         if (ele.auto)
+            clearTimeout(ele.auto);
+         ele.auto = setTimeout(function() {drawCanvas(id, dly)}, ele.dly);
+      }
       ele.dly = dly;
    }
    try {req.send(null);}
@@ -247,14 +247,14 @@ function csMouseUp(cvs) {
    cvs.csDn = false;
    if (cvs.clicked) {
       clearTimeout(cvs.clicked);
-      cvs.clicked = false;
+      cvs.clicked = null;
       return drawCanvas(cvs.id, cvs.dly, 2, cvs.csDnX, cvs.csDnY);
    }
    if (cvs.csMv)
-      return drawCanvas(cvs.id, cvs.dly);
+      return drawCanvas(cvs.id, cvs.dly, "$T");
    cvs.clicked = setTimeout(
       function() {
-         cvs.clicked = false;
+         cvs.clicked = null;
          drawCanvas(cvs.id, cvs.dly, 1, cvs.csDnX, cvs.csDnY);
       },
       200 );
@@ -264,7 +264,7 @@ function csMouseUp(cvs) {
 function csTouchEnd(cvs) {
    cvs.csDn = false;
    if (cvs.csMv)
-      return drawCanvas(cvs.id, cvs.dly);
+      return drawCanvas(cvs.id, cvs.dly, "$T");
    return false;
 }
 
@@ -273,9 +273,9 @@ function csLeave(cvs) {
    cvs.csDn = cvs.csMv = false;
    if (cvs.clicked) {
       clearTimeout(cvs.clicked);
-      cvs.clicked = false;
+      cvs.clicked = null;
    }
-   return drawCanvas(cvs.id, cvs.dly);
+   return drawCanvas(cvs.id, cvs.dly, "$T");
 }
 
 function csCursor(cvs, x, y) {
