@@ -1,4 +1,4 @@
-/* 21nov21 Software Lab. Alexander Burger */
+/* 05apr22 Software Lab. Alexander Burger */
 
 var FormReq = new XMLHttpRequest();
 FormReq.upload.addEventListener("progress", dropProgress, false);
@@ -12,7 +12,7 @@ function inBtn(btn,flg) {InBtn = flg;}
 
 function formKey(event) {
    Key = event.keyCode;
-   if (Hint  &&  Hint.style.visibility == "visible") {
+   if (Hint  &&  event.charCode == 0  &&  Hint.style.visibility == "visible") {
       if ((Item >= 0 && Key == 13) || Key == 38 || Key == 40)
          return false;
       if (Key == 13) {
@@ -24,7 +24,7 @@ function formKey(event) {
          return false;
       }
    }
-   if (event.charCode || event.keyCode == 8)
+   if (event.charCode || Key == 8)
       Chg = true;
    return true;
 }
@@ -291,10 +291,10 @@ function post(form, auto, exe, file) {
             }
             if (Post)
                Post();
-            Busy = false;
             Chg = false;
          }
       }
+      Busy = false;
       form.style.cursor = "";
       if (Queue.length > 0) {
          var a = Queue.shift();
@@ -388,7 +388,7 @@ function hintKey(field, event, tok, coy) {
 
    if (event.keyCode == 9 || event.keyCode == 27)
       return false;
-   if (Hint.style.visibility == "visible") {
+   if (event.charCode == 0  &&  Hint.style.visibility == "visible") {
       if (Item >= 0 && event.keyCode == 13) {
          setHint(field, Hints.childNodes[Item]);
          return false;
@@ -539,7 +539,9 @@ function tblMove(table, event) {
          TblY = event.touches[0].pageY;
          for (var obj = table.parentNode;  obj;  obj = obj.parentNode)
             if (obj.tagName == "FORM")
-               return post(obj, false, [dy > 6? "jsUp" : "jsDn"], null);
+               return post(obj, false,
+                  [dy > 6? "jsUp" : "jsDn", "+" + table.getAttribute("chart")],
+                  null );
       }
       return false;
    }
@@ -587,7 +589,6 @@ function lispVal(x) {
 }
 
 function ping(min) {
-   Busy = false;
    if (SesId)
       setTimeout(function() {ping1(min)}, 20000);
 }
