@@ -1,4 +1,4 @@
-// 29may22 Software Lab. Alexander Burger
+// 13jan23 Software Lab. Alexander Burger
 
 #include "pico.h"
 
@@ -14,7 +14,8 @@ char *stderrMsg(char *fmt, char *s) {
 }
 
 void gPrintf(char *buf, int32_t siz, char *fmt, char *arg) {
-   snprintf(buf, siz, fmt, arg);
+   if (snprintf(buf, siz, fmt, arg) >= siz)
+      fprintf(stderr, "!! gPrintf() truncated !!\n");
 }
 
 char *strErrno(void) {
@@ -255,7 +256,7 @@ int32_t gErrno(void) {
 }
 
 // Terminal
-int Tio;
+char Tio;
 struct termios OrgTermio;
 struct termios *Termio;
 
@@ -267,11 +268,12 @@ void stopTerm(void) {
    sigset_t mask;
 
    if (Tio) {
-      tcSet(&OrgTermio);
       sigUnblock(SIGTSTP);
       signal(SIGTSTP, SIG_DFL),  raise(SIGTSTP);
       if (Termio)
          tcSet(Termio);
+      else
+         tcSet(&OrgTermio);
    }
 }
 
@@ -288,6 +290,7 @@ void setRaw(void) {
 }
 
 void setCooked(void) {
+   rl_deprep_terminal();
    if (Termio) {
       tcSet(&OrgTermio);
       free(Termio),  Termio = NULL;
@@ -325,13 +328,15 @@ int64_t getMsec(void) {
 }
 
 int64_t getDate(void) {
-   gettimeofday(&Tv, NULL);
+   if (gettimeofday(&Tv, NULL))
+      return 0;
    Time = localtime(&Tv.tv_sec);
    return Time->tm_year+1900 | (Time->tm_mon+1) << 16 | Time->tm_mday << 24;
 }
 
 int64_t getGmDate(void) {
-   gettimeofday(&Tv, NULL);
+   if (gettimeofday(&Tv, NULL))
+      return 0;
    Time = gmtime(&Tv.tv_sec);
    return Time->tm_year+1900 | (Time->tm_mon+1) << 16 | Time->tm_mday << 24;
 }
@@ -339,7 +344,8 @@ int64_t getGmDate(void) {
 int64_t getTime(void) {
    struct tm *p;
 
-   gettimeofday(&Tv, NULL);
+   if (gettimeofday(&Tv, NULL))
+      return 0;
    p = localtime(&Tv.tv_sec);
    return p->tm_hour * 3600 + p->tm_min * 60 + p->tm_sec;
 }
@@ -356,14 +362,14 @@ char *ulimStk(void) {
    return (char*)&stk - stk.rlim_cur + 16384;
 }
 
-int64_t fileInfo(int lnk, char *nm, int64_t *siz) {
+int64_t fileInfo(int lnk, int loc, char *nm, int64_t *siz) {
    int64_t n;
    struct tm *p;
    struct stat st;
 
    if ((lnk? stat(nm, &st) : lstat(nm, &st)) < 0)
       return -1;
-   p = gmtime(&st.st_mtime);
+   p = loc? localtime(&st.st_mtime) : gmtime(&st.st_mtime);
    n = (p->tm_year+1900 | (p->tm_mon+1) << 16 | p->tm_mday << 24 |
          (int64_t)(p->tm_hour * 3600 + p->tm_min * 60 + p->tm_sec) << 32 ) << 2;
    if ((st.st_mode & S_IFMT) == S_IFDIR)
@@ -392,6 +398,7 @@ void pollIgn(struct pollfd *p) {
 int32_t gPoll(struct pollfd *fds, int32_t nfds, int64_t timeout) {
 #ifdef __linux__
    struct timespec ts, *tp;
+   extern int ppoll(struct pollfd *fds, nfds_t nfds, const struct timespec *tmo_p, const sigset_t *sigmask);
 
    if (timeout == 9223372036854775807) {  // 292MY
       int i = nfds;
@@ -513,7 +520,7 @@ any box64(any x) {
 #define FMAX ((float)UINT64_MAX)
 #define DMAX ((double)UINT64_MAX)
 
-int Fsign;
+char Fsign;
 uint64_t Fdigit;
 
 static union {
